#!/bin/sh
# ssh-permissions script for linux
# ─< ANSI color codes >───────────────────────────────────────────────────────────────────
RED='\033[0;31m'
CYAN='\033[0;36m'
YELLOW='\033[0;33m'
LIGHT_GREEN='\033[0;92m'
BOLD='\033[1m'
NC='\033[0m' # No Color

echo_error() {
  printf "${BOLD}${RED}ERROR: ${NC}${RED}%s${NC}\n" "$1" >&2
}

echo_info() {
  printf "${BOLD}${CYAN}INFO: ${NC}${CYAN}%s${NC}\n" "$1"
}

echo_warning() {
  printf "${BOLD}${YELLOW}WARNING: ${NC}${YELLOW}%s${NC}\n" "$1"
}

echo_note() {
  printf "${BOLD}${LIGHT_GREEN}NOTE: ${NC}${LIGHT_GREEN}%s${NC}\n" "$1"
}

# ─< Check if the user is root and set sudo variable if necessary >───────────────────────
check_root() {
  if [ "$(id -u)" -ne 0 ]; then
    if command -v sudo >/dev/null; then
      echo_info "User is not root. Using sudo for privileged operations."
      _sudo="sudo"
    else
      echo_error "No sudo found and you're not root! Can't install packages."
      return 1
    fi
  else
    echo_note "Root access confirmed."
    _sudo=""
  fi
}

set_perm() {
  check_root
  if [[ -d "$HOME/.ssh" ]]; then
    echo_note "chmod 700 $HOME/.ssh"
    "$_sudo" chmod 700 $HOME/.ssh >/dev/null 2>&1
    if ls $HOME/.ssh/*.pub >/dev/null 2>&1; then
      echo_note "chmod 600 $HOME/.ssh/*id*"
      "$_sudo" chmod 600 $HOME/.ssh/*id* >/dev/null 2>&1
      echo_note "chmod 666 $HOME/.ssh/*.pub"
      "$_sudo" chmod 666 $HOME/.ssh/*.pub >/dev/null 2>&1
    else
      echo_error "There is no *.pub file in the $HOME/.ssh/ directory! Aborting now!"
    fi
  else
    echo_error "No .ssh folder found in $HOME - exiting now!"
    exit 1
  fi
}

set_perm
